@@ -1,11 +1,8 @@
-use warnings;
-use strict;
-
 package SVN::Hooks;
-{
-  $SVN::Hooks::VERSION = '1.26';
-}
-# ABSTRACT: A framework for implementing Subversion hooks.
+# ABSTRACT: Framework for implementing Subversion hooks
+$SVN::Hooks::VERSION = '1.28';
+use strict;
+use warnings;
 
 use File::Basename;
 use File::Spec::Functions;
@@ -35,11 +32,11 @@ sub run_hook {
     foreach my $conf (@Conf_Files) {
 	my $conffile = file_name_is_absolute($conf) ? $conf : catfile($Repo, $conf);
 	next unless -e $conffile; # Configuration files are optional
+
+        # The configuration file must be evaluated in the main:: namespace
 	package main;
-{
-  $main::VERSION = '1.26';
-}
-	unless (my $return = do $conffile) {
+$main::VERSION = '1.28';
+unless (my $return = do $conffile) {
 	    die "couldn't parse '$conffile': $@\n" if $@;
 	    die "couldn't do '$conffile': $!\n"    unless defined $return;
 	    die "couldn't run '$conffile'\n"       unless $return;
@@ -78,6 +75,7 @@ sub run_hook {
 sub POST_COMMIT (&) {
     my ($hook) = @_;
     push @{$Hooks{'post-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-lock(repos-path, username)
@@ -85,6 +83,7 @@ sub POST_COMMIT (&) {
 sub POST_LOCK (&) {
     my ($hook) = @_;
     push @{$Hooks{'post-lock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-revprop-change(SVN::Look, username, property-name, action)
@@ -92,6 +91,7 @@ sub POST_LOCK (&) {
 sub POST_REVPROP_CHANGE (&) {
     my ($hook) = @_;
     push @{$Hooks{'post-revprop-change'}}, sub { $hook->(@_); };
+    return;
 }
 
 # post-unlock(repos-path, username)
@@ -99,6 +99,7 @@ sub POST_REVPROP_CHANGE (&) {
 sub POST_UNLOCK (&) {
     my ($hook) = @_;
     push @{$Hooks{'post-unlock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-commit(SVN::Look)
@@ -106,6 +107,7 @@ sub POST_UNLOCK (&) {
 sub PRE_COMMIT (&) {
     my ($hook) = @_;
     push @{$Hooks{'pre-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-lock(repos-path, path, username, comment, steal-lock-flag)
@@ -113,6 +115,7 @@ sub PRE_COMMIT (&) {
 sub PRE_LOCK (&) {
     my ($hook) = @_;
     push @{$Hooks{'pre-lock'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-revprop-change(SVN::Look, username, property-name, action)
@@ -120,6 +123,7 @@ sub PRE_LOCK (&) {
 sub PRE_REVPROP_CHANGE (&) {
     my ($hook) = @_;
     push @{$Hooks{'pre-revprop-change'}}, sub { $hook->(@_); };
+    return;
 }
 
 # pre-unlock(repos-path, path, username, lock-token, break-unlock-flag)
@@ -127,13 +131,15 @@ sub PRE_REVPROP_CHANGE (&) {
 sub PRE_UNLOCK (&) {
     my ($hook) = @_;
     push @{$Hooks{'pre-unlock'}}, sub { $hook->(@_); };
+    return;
 }
 
-# start-commit(repos-path, username, capabilities)
+# start-commit(repos-path, username, capabilities, txt-name)
 
 sub START_COMMIT (&) {
     my ($hook) = @_;
     push @{$Hooks{'start-commit'}}, sub { $hook->(@_); };
+    return;
 }
 
 ## use critic
@@ -148,11 +154,11 @@ __END__
 
 =head1 NAME
 
-SVN::Hooks - A framework for implementing Subversion hooks.
+SVN::Hooks - Framework for implementing Subversion hooks
 
 =head1 VERSION
 
-version 1.26
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -163,7 +169,7 @@ A single script can implement several hooks:
 	use SVN::Hooks;
 
 	START_COMMIT {
-	    my ($repo_path, $username, $capabilities) = @_;
+	    my ($repo_path, $username, $capabilities, $txt_name) = @_;
 	    # ...
 	};
 
@@ -340,7 +346,7 @@ L<SVN::Look> documentation to know how to use it.)
 
 =item * PRE_UNLOCK(repos-path, path, username, lock-token, break-unlock-flag)
 
-=item * START_COMMIT(repos-path, username, capabilities)
+=item * START_COMMIT(repos-path, username, capabilities, txt-name)
 
 =back
 
@@ -353,7 +359,7 @@ This is an example of a script implementing two hooks:
 	# ...
 
 	START_COMMIT {
-	    my ($repos_path, $username, $capabilities) = @_;
+	    my ($repos_path, $username, $capabilities, $txt_name) = @_;
 
 	    exists $committers{$username}
 		or die "User '$username' is not allowed to commit.\n";
@@ -549,7 +555,7 @@ called, like this:
 
 =over
 
-=item * start-commit repo-path user capabilities
+=item * start-commit repo-path user capabilities txt-name
 
 =item * pre-commit repo-path txn
 
@@ -574,13 +580,17 @@ the hooks, you usually call C<run_hook> like this:
 
 	run_hook($0, @ARGV);
 
+=head1 REPOSITORY
+
+L<https://github.com/gnustavo/SVN-Hooks>
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
