@@ -1,12 +1,9 @@
+package SVN::Hooks::CheckCapability;
+# ABSTRACT: Check the svn client capabilities.
+$SVN::Hooks::CheckCapability::VERSION = '1.28';
 use strict;
 use warnings;
 
-package SVN::Hooks::CheckCapability;
-{
-  $SVN::Hooks::CheckCapability::VERSION = '1.26';
-}
-# ABSTRACT: Check the svn client capabilities.
-
 use Carp;
 use SVN::Hooks;
 
@@ -26,7 +23,7 @@ sub CHECK_CAPABILITY {
 }
 
 sub start_commit {
-    my ($repo_path, $user, $capabilities) = @_;
+    my ($repo_path, $user, $capabilities, $txt_name) = @_;
 
     $capabilities ||= ''; # pre 1.5 svn clients don't pass the capabilities
 
@@ -58,7 +55,7 @@ SVN::Hooks::CheckCapability - Check the svn client capabilities.
 
 =head1 VERSION
 
-version 1.26
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -90,7 +87,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
