@@ -1,9 +1,6 @@
 package SVN::Hooks::Generic;
-{
-  $SVN::Hooks::Generic::VERSION = '1.27';
-}
 # ABSTRACT: Implement generic checks for all Subversion hooks.
-
+$SVN::Hooks::Generic::VERSION = '1.28';
 use strict;
 use warnings;
 
@@ -55,7 +52,7 @@ SVN::Hooks::Generic - Implement generic checks for all Subversion hooks.
 
 =head1 VERSION
 
-version 1.27
+version 1.28
 
 =head1 SYNOPSIS
 
@@ -100,7 +97,7 @@ The function signatures are the following:
 
 =item pre-unlock(repos-path, path, username, lock-token, break-unlock-flag)
 
-=item start-commit(repos-path, username, capabilities)
+=item start-commit(repos-path, username, capabilities, txt-name)
 
 =back
 
@@ -112,7 +109,7 @@ performing the Subversion action which triggered the hook.
 The sketch below shows how this directive could be used.
 
 	sub my_start_commit {
-	    my ($repo_path, $username, $capabilities) = @_;
+	    my ($repo_path, $username, $capabilities, $txt_name) = @_;
 	    # ...
 	}
 
@@ -132,7 +129,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
